Francesco Romani has uploaded a new change for review.

Change subject: profiling: disambiguate messages and docstrings
......................................................................

profiling: disambiguate messages and docstrings

Upcoming patches want to add memory profiling,
so the CPU profiling will not be the only one.

This patch changes the messages to reflect that.

Change-Id: Ia43159009318295313855a16688b249982e40b34
Signed-off-by: Francesco Romani <[email protected]>
---
M lib/vdsm/profiling/cpu.py
1 file changed, 5 insertions(+), 5 deletions(-)


  git pull ssh://gerrit.ovirt.org:29418/vdsm refs/changes/11/36011/1

diff --git a/lib/vdsm/profiling/cpu.py b/lib/vdsm/profiling/cpu.py
index 7ee3240..916892c 100644
--- a/lib/vdsm/profiling/cpu.py
+++ b/lib/vdsm/profiling/cpu.py
@@ -49,13 +49,13 @@
 
 
 def start():
     """ Starts application wide profiling """
     if is_enabled():
         _start_profiling(_CLOCK, _BUILTINS, _THREADS)
 
 
 def stop():
     """ Stops application wide profiling """
     if is_enabled():
         _stop_profiling(_FILENAME, _FORMAT)
 
@@ -92,20 +92,20 @@
 
 def _start_profiling(clock, builtins, threads):
     global yappi
-    logging.debug("Starting profiling")
+    logging.debug("Starting CPU profiling")
     with _lock:
         import yappi
         # yappi start semantics are a bit too liberal, returning success if
         # yappi is already started, happily having too different code paths
         # that thinks they own the single process profiler.
         if yappi.is_running():
-            raise Error('Profiler is already running')
+            raise Error('CPU profiler is already running')
         yappi.set_clock_type(clock)
         yappi.start(builtins=builtins, profile_threads=threads)
 
 
 def _stop_profiling(filename, format):
-    logging.debug("Stopping profiling")
+    logging.debug("Stopping CPU profiling")
     with _lock:
         if yappi.is_running():
             yappi.stop()
@@ -49,13 +49,13 @@
 
 def start():
-    """ Starts application wide profiling """
+    """ Starts application wide CPU profiling """
     if is_enabled():
         _start_profiling(_CLOCK, _BUILTINS, _THREADS)
@@ -49,13 +49,13 @@
 
 def stop():
-    """ Stops application wide profiling """
+    """ Stops application wide CPU profiling """
     if is_enabled():
         _stop_profiling(_FILENAME, _FORMAT)


-- 
To view, visit http://gerrit.ovirt.org/36011
To unsubscribe, visit http://gerrit.ovirt.org/settings

Gerrit-MessageType: newchange
Gerrit-Change-Id: Ia43159009318295313855a16688b249982e40b34
Gerrit-PatchSet: 1
Gerrit-Project: vdsm
Gerrit-Branch: master
Gerrit-Owner: Francesco Romani <[email protected]>
_______________________________________________
vdsm-patches mailing list
[email protected]
https://lists.fedorahosted.org/mailman/listinfo/vdsm-patches

Reply via email to